@@ -2,7 +2,6 @@
 from __future__ import absolute_import, unicode_literals, division
 import bottle
 from . import http
-from armet import utils
 
 
 class Resource(object):
@@ -18,13 +17,13 @@ class Resource(object):
         if async:
             # Defer the view to pass of control.
             import gevent
-            gevent.spawn(utils.super(Resource, cls).view, request, response)
+            gevent.spawn(super(Resource, cls).view, request, response)
 
             # Construct and return a streamer.
             return cls.stream(response, response)
 
         # Pass control off to the resource handler.
-        return utils.super(Resource, cls).view(request, response)
+        return super(Resource, cls).view(request, response)
 
     @classmethod
     def mount(cls, url='/', application=None):
